@@ -24,8 +24,6 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 #  USA
 
-from __future__ import absolute_import, print_function
-
 import apt_pkg
 import datetime
 import dbus
@@ -48,10 +46,13 @@ gi.require_version("PackageKitGlib", "1.0")
 from gi.repository import PackageKitGlib as packagekit
 from gi.repository import GObject, Gdk, Gtk, Gio, GLib, Handy
 
+from aptsources.sourceslist import Deb822SourceEntry
+
 from .SimpleGtkbuilderApp import SimpleGtkbuilderApp
 from .DialogAdd import DialogAdd
 from .DialogMirror import DialogMirror
 from .DialogEdit import DialogEdit
+from .DialogEditDeb822 import DialogEditDeb822
 from .DialogCacheOutdated import DialogCacheOutdated
 from .DialogAddSourcesList import DialogAddSourcesList
 from .UbuntuProPage import UbuntuProPage
@@ -159,7 +160,8 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
         """ Provide a GTK based graphical user interface to configure
             the used software repositories, corresponding authentication keys
             and update automation """
-        SoftwareProperties.__init__(self, options=options, datadir=datadir)
+        SoftwareProperties.__init__(self, options=options, datadir=datadir,
+                                    deb822=True)
         Gtk.Window.set_default_icon_name("software-properties")
 
         # Support GNOME 42 dark mode
@@ -250,8 +252,9 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
         self.show_distro()
         # Setup and show the Additonal Drivers tab
         self.init_drivers()
-        # Setup and show the Ubuntu Pro tab
-        self.init_ubuntu_pro()
+        # Setup and show the Ubuntu Pro tab if the serie is a LTS
+        if is_current_distro_lts():
+            self.init_ubuntu_pro()
 
         # Connect to switch-page before setting initial tab. Otherwise the
         # first switch goes unnoticed.
@@ -294,7 +297,7 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
         i = self.get_release_upgrades_policy()
         self.combobox_release_upgrades.set_active(i)
         self.handlers[self.combobox_release_upgrades] = \
-             self.combobox_release_upgrades.connect("changed", 
+             self.combobox_release_upgrades.connect("changed",
                                                     self.on_combobox_release_upgrades_changed)
     def init_apt_cache(self):
         apt_pkg.init_config()
@@ -1102,8 +1105,13 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
         if not iter:
             return
         old_source_entry = model.get_value(iter, LIST_ENTRY_OBJ)
-        dialog = DialogEdit(self.window_main, self.sourceslist,
-                            old_source_entry, self.datadir)
+
+        if isinstance(old_source_entry, Deb822SourceEntry):
+            dialog = DialogEditDeb822(self.window_main, self.sourceslist,
+                                      old_source_entry, self.datadir)
+        else:
+            dialog = DialogEdit(self.window_main, self.sourceslist,
+                                old_source_entry, self.datadir)
         if dialog.run() == Gtk.ResponseType.OK:
             try:
                 self.backend.ReplaceSourceEntry(str(old_source_entry),
