@@ -45,8 +45,9 @@ from softwareproperties.SoftwareProperties import SoftwareProperties
 import softwareproperties.SoftwareProperties
 from .I18nHelper import *
 
-from aptsources.sourceslist import SourceEntry
+from aptsources.sourceslist import Deb822SourceEntry, SourceEntry
 from .DialogEdit import DialogEdit
+from .DialogEditDeb822 import DialogEditDeb822
 from .DialogAdd import DialogAdd
 from .DialogMirror import DialogMirror
 from .CdromProgress import CdromProgress
@@ -80,7 +81,8 @@ class SoftwarePropertiesQt(SoftwareProperties):
     """ Provide a Qt-based graphical user interface to configure
         the used software repositories, corresponding authentication keys
         and update automation """
-    SoftwareProperties.__init__(self, options=options, datadir=datadir)
+    SoftwareProperties.__init__(self, options=options, datadir=datadir,
+                                deb822=True)
 
     self.options = options
     self.datadir = datadir
@@ -690,9 +692,14 @@ class SoftwarePropertiesQt(SoftwareProperties):
     item = self.userinterface.treeview_sources.currentItem()
     if item is not None:
         index = self.userinterface.treeview_sources.indexOfTopLevelItem(item)
-        dialogue = DialogEdit(self.userinterface, self.sourceslist, self.isv_sources[index], self.datadir)
+        if isinstance(self.isv_sources[index], Deb822SourceEntry):
+            dialogue = DialogEditDeb822(self.userinterface, self.sourceslist, self.isv_sources[index], self.datadir)
+        else:
+            dialogue = DialogEdit(self.userinterface, self.sourceslist, self.isv_sources[index], self.datadir)
         result = dialogue.run()
         if result == QDialog.Accepted:
+            self.replace_source_entry(str(self.isv_sources[index]),
+                                      str(dialogue.new_source_entry))
             self.set_modified_sourceslist()
             self.show_isv_sources()
 
