@@ -8,6 +8,7 @@ import tempfile
 import unittest
 
 from aptsources.distro import get_distro
+from aptsources.sourceslist import (SourceEntry, Deb822SourceEntry)
 from copy import copy
 from pathlib import Path
 from types import SimpleNamespace
@@ -15,7 +16,7 @@ from urllib.request import urlopen
 from urllib.error import (URLError, HTTPError)
 
 from softwareproperties.cloudarchive import RELEASE_MAP
-from softwareproperties.extendedsourceslist import SourceEntry
+from softwareproperties.sourceutils import replace_source_entry
 
 
 CODENAME = get_distro().codename
@@ -46,8 +47,7 @@ ARCHIVE_FILENAME = f'archive_uri-{ARCHIVE_FILENAME_URI}-{CODENAME}.list'
 
 PPA_NAME = 'ubuntu-support-team/software-properties-autopkgtest'
 PPA_URI = f'https://ppa.launchpadcontent.net/{PPA_NAME}/ubuntu/'
-PPA_FILENAME = f'ubuntu-support-team-ubuntu-software-properties-autopkgtest-{CODENAME}.list'
-PPA_TRUSTED_FILENAME = 'ubuntu-support-team-ubuntu-software-properties-autopkgtest.gpg'
+PPA_FILENAME = f'ubuntu-support-team-ubuntu-software-properties-autopkgtest-{CODENAME}.sources'
 PPA_TRUSTED_FINGERPRINT = 'A17A D76F CBB7 A7D5 73C4  DF43 1E03 2FCE 2F88 6048'
 
 ADD_APT_REPOSITORY_LONG_PARAMS = SimpleNamespace(
@@ -92,6 +92,20 @@ def line(uri=None, binary=True, pocket=None, components=None):
     components = ' '.join(components or MAIN)
     return f'{deb} {uri} {CODENAME}{pocket} {components}'
 
+def deb822_lines(uri=None, binary=True, source=False, pocket=None, components=None):
+    uris = uri or FAKE_URI
+
+    suites = f'{CODENAME}' + (f'-{pocket}' if pocket else '')
+
+    types = [TYPE_BINARY] if binary else []
+    types += [TYPE_SOURCE] if source else []
+    types = ' '.join(types)
+
+    components = components or MAIN
+    components = ' '.join(components)
+
+    return [f'Types: {types}',f'URIs: {uris}', f'Suites: {suites}', f'Components: {components}']
+
 
 @unittest.skipIf(ADD_APT_REPOSITORY is None, 'Could not find add-apt-repository script')
 class TestAddAptRepository(unittest.TestCase):
@@ -220,9 +234,11 @@ class TestAddAptRepository(unittest.TestCase):
 
     def check_sourceentry(self, expected_line, content_lines):
         expected_entry = SourceEntry(expected_line)
+        expected_entry.comps = set(expected_entry.comps)
 
         for (index, line) in enumerate(content_lines):
             entry = SourceEntry(line)
+            entry.comps = set(entry.comps)
             if entry == expected_entry:
                 return content_lines[:index] + content_lines[index+1:]
 
@@ -240,6 +256,33 @@ class TestAddAptRepository(unittest.TestCase):
             unexpected_lines = '\n'.join(lines)
             self.fail(f"Unexpected lines:\n{unexpected_lines}")
 
+    def check_expected_deb822_lines(self, expected_lines, lines):
+        def filter_lines(lines):
+            in_ignored_field = False
+            for line in lines:
+                if line.startswith('Signed-By:'):
+                    in_ignored_field = True
+                    continue
+
+                if in_ignored_field and line.startswith(' '):
+                    continue
+
+                in_ignored_field = False
+                yield line
+
+        # Ignore lines that should be there, but we are not checking for, e.g.
+        # Signed-By.
+        lines = filter_lines(lines)
+        missing_lines = list(set(expected_lines) - set(lines))
+        unexpected_lines = list(set(lines) - set(expected_lines))
+
+
+        if missing_lines:
+            self.fail(f'Missing lines: {missing_lines} in: {lines}')
+
+        if unexpected_lines:
+            self.fail(f'Unexpected lines: {unexpected_lines} in: {lines}')
+
     def apt_get_output_lines(self):
         try:
             return self.apt_get_output.read_text().splitlines()
@@ -260,13 +303,27 @@ class TestAddAptRepository(unittest.TestCase):
         if not self.testing_ppa:
             return
 
-        self.assertIsNotNone(self.trustedfile)
+        with open(self.sourcesfile, mode='r', encoding='utf-8') as f:
+            entry = Deb822SourceEntry(f.read(), '')
 
-        with tempfile.TemporaryDirectory() as homedir:
-            Path(homedir).chmod(0o700) # so gpg doesn't complain to stderr
-            cmd = f'gpg -q --homedir {homedir} --no-default-keyring --keyring {self.trustedfile} --fingerprint'
-            result = subprocess.run(cmd.split(), stdout=subprocess.PIPE, encoding='UTF-8')
-            self.assertIn(PPA_TRUSTED_FINGERPRINT, result.stdout)
+        keydata = entry.section.get('Signed-By')
+        keydata = keydata.splitlines()
+        keydata = [l.lstrip() for l in keydata]
+        keydata = [l if l != '.' else '' for l in keydata]
+        keydata = '\n'.join(keydata)
+
+        with tempfile.NamedTemporaryFile(mode='w') as f:
+            f.write(keydata)
+            f.flush()
+
+            with tempfile.TemporaryDirectory() as homedir:
+                Path(homedir).chmod(0o700) # so gpg doesn't complain to stderr
+                cmd = f'gpg -q --homedir {homedir} --import {f.name}'
+                subprocess.check_call(cmd.split())
+                keyring = os.path.join(homedir, 'pubring.kbx')
+                cmd = f'gpg -q --homedir {homedir} --no-default-keyring --keyring {keyring} --fingerprint'
+                result = subprocess.run(cmd.split(), stdout=subprocess.PIPE, encoding='UTF-8')
+                self.assertIn(PPA_TRUSTED_FINGERPRINT, result.stdout)
 
     def check_file(self, testfile, exists=True):
         if not testfile:
@@ -283,7 +340,10 @@ class TestAddAptRepository(unittest.TestCase):
         self.check_file(self.sourcesfile)
         self.check_file(self.trustedfile)
 
-        self.check_expected_lines(expected_lines, self.sourcesfile.read_text().splitlines())
+        if self.testing_ppa:
+            self.check_expected_deb822_lines(expected_lines, self.sourcesfile.read_text().splitlines())
+        else:
+            self.check_expected_lines(expected_lines, self.sourcesfile.read_text().splitlines())
 
         self.check_apt_get_update()
         self.check_ppa_gpgkey()
@@ -297,10 +357,13 @@ class TestAddAptRepository(unittest.TestCase):
         self.check_file(self.trustedfile)
 
     def run_sourceslistd_test(self, args, expected_line):
-        source_entry = SourceEntry(expected_line)._replace(type=TYPE_SOURCE)
-        source_entry.set_enabled(self.enable_source > 0)
+        if self.testing_ppa:
+            expected_lines = deb822_lines(uri=PPA_URI)
+        else:
+            source_entry = replace_source_entry(SourceEntry(expected_line), type=TYPE_SOURCE)
+            source_entry.set_enabled(self.enable_source > 0)
 
-        expected_lines = [expected_line, str(source_entry)]
+            expected_lines = [expected_line, str(source_entry)]
         test_args = self.parameter_all
         test_args += args
         self.run_sourceslistd_add_remove_test(test_args, expected_lines)
@@ -329,7 +392,7 @@ class TestAddAptRepository(unittest.TestCase):
         self.testing_ppa = True
 
         self.sourcesfile = PPA_FILENAME
-        self.trustedfile = PPA_TRUSTED_FILENAME
+        self.trustedfile = None
         args = []
         if with_param:
             args += [self.params.ppa]
@@ -337,7 +400,7 @@ class TestAddAptRepository(unittest.TestCase):
             args += [f'ppa:{PPA_NAME}']
         else:
             args += [PPA_NAME]
-        self.run_sourceslistd_test(args, self.line(uri=PPA_URI))
+        self.run_sourceslistd_test(args, None)
 
     def test_ppa_noupdate(self):
         self.noupdate = True
@@ -584,9 +647,9 @@ class TestAddAptRepository(unittest.TestCase):
         self._test_pocket()
 
     def add_lines_es(self, group, pocket, components, /, binary=True, disabled=False, alone=False, plus_comps=[], minus_comps=False):
-        binary_entry = group.entry(pocket=pocket, components=components)._replace(disabled=disabled)
+        binary_entry = replace_source_entry(group.entry(pocket=pocket, components=components), disabled=disabled)
         enabled_source_entry = group.entry(binary=False, pocket=pocket, components=components)
-        disabled_source_entry = enabled_source_entry._replace(disabled=True)
+        disabled_source_entry = replace_source_entry(enabled_source_entry, disabled=True)
 
         if binary:
             binary_line = str(binary_entry)
@@ -609,8 +672,8 @@ class TestAddAptRepository(unittest.TestCase):
             if plus_comps and self.enable_source > 1:
                 # include comps from other binary-only lines
                 comps = set(enabled_source_entry.comps) | set(plus_comps)
-                enabled_line = str(enabled_source_entry._replace(comps=comps))
-                disabled_line = str(disabled_source_entry._replace(comps=comps))
+                enabled_line = str(replace_source_entry(enabled_source_entry, comps=comps))
+                disabled_line = str(replace_source_entry(disabled_source_entry, comps=comps))
             if disabled and alone:
                 # with source, 'alone' indicates no matching (enabled) binary line exists,
                 # so the source line will *not* be enabled
